# Intel

The {py:mod}`torii.platform.vendor.intel` module provides a base platform to support Intel toolchains with the [Quartus] and [Mistral] toolchains.

```{eval-rst}

.. autoclass:: torii.platform.vendor.intel.IntelPlatform

```


[Quartus]: https://www.intel.com/content/www/us/en/products/details/fpga/development-tools/quartus-prime.html
[Mistral]: https://github.com/Ravenslofty/mistral
